@@ -28,6 +28,7 @@ using System;
 using Gdk;
 using Gtk;
 using Mono.Unix;
+using System.IO;
 
 namespace Pinta.Core
 {
@@ -165,14 +166,12 @@ namespace Pinta.Core
 				// Open the image and add it to the layers
 				Layer layer = doc.AddNewLayer (System.IO.Path.GetFileName (file));
 
-				Pixbuf bg = new Pixbuf (file, doc.ImageSize.Width, doc.ImageSize.Height, true);
-				
-				using (Cairo.Context g = new Cairo.Context (layer.Surface)) {
-					CairoHelper.SetSourcePixbuf (g, bg, 0, 0);
-					g.Paint ();
-				}
-				
-				bg.Dispose ();
+				using (var fs = new FileStream (file, FileMode.Open))
+					using (Pixbuf bg = new Pixbuf (fs))
+						using (Cairo.Context g = new Cairo.Context (layer.Surface)) {
+							CairoHelper.SetSourcePixbuf (g, bg, 0, 0);
+							g.Paint ();
+						}
 
 				doc.SetCurrentLayer (layer);
 
