@@ -93,10 +93,9 @@ namespace Pinta.Core
 				doc.PathAndFileName = filename;
 			
 			OpenDocuments.Add (doc);
-			active_document_index = OpenDocuments.Count - 1;
-			
 			OnDocumentCreated (new DocumentEventArgs (doc));
-			OnActiveDocumentChanged (EventArgs.Empty);
+
+			SetActiveDocument (doc);
 			
 			return doc;
 		}
@@ -246,7 +245,10 @@ namespace Pinta.Core
 
 		internal void SetActiveDocumentInternal (Document document)
 		{
-			PintaCore.Tools.Commit ();
+			// Work around a case where we closed a document but haven't updated
+			// the active_document_index yet and it points to the closed document
+			if (HasOpenDocuments && OpenDocuments.Count > active_document_index)
+				PintaCore.Tools.Commit ();
 
 			int index = OpenDocuments.IndexOf (document);
 			active_document_index = index;
