@@ -31,7 +31,7 @@ using Mono.Unix;
 
 namespace Pinta.Tools
 {
-	//[System.ComponentModel.Composition.Export (typeof (BaseTool))]
+	//[System.ComponentModel.Composition (typeof (BaseTool))]
 	public class MoveSelectedTool : BaseTool
 	{
 		private PointD origin_offset;
@@ -136,7 +136,11 @@ namespace Pinta.Tools
 
 		protected override void OnCommit ()
 		{
-			PintaCore.Workspace.ActiveDocument.FinishSelection ();
+			try {
+				PintaCore.Workspace.ActiveDocument.FinishSelection ();
+			} catch (Exception) {
+				// Ignore an error where ActiveDocument fails.
+			}
 		}
 
 		protected override void OnDeactivated ()
