@@ -34,7 +34,7 @@ using Pinta.Tools.Brushes;
 
 namespace Pinta.Tools
 {
-	//[System.ComponentModel.Composition.Export (typeof (BaseTool))]
+	//[System.ComponentModel.Composition (typeof (BaseTool))]
 	public class PaintBrushTool : BaseBrushTool
 	{
 		#region Properties
@@ -48,6 +48,7 @@ namespace Pinta.Tools
 		public Color FillColor { get; private set; }
 		public Point LastPoint { get; private set; }
 		public Cairo.Context Drawable { get; private set; }
+		public ImageSurface Surface { get; private set; }
 		#endregion
 
 		private PaintBrush default_brush;
@@ -118,7 +119,7 @@ namespace Pinta.Tools
 
 			int x = (int)point.X;
 			int y = (int)point.Y;
-			
+
 			if (LastPoint.Equals (point_empty))
 				LastPoint = new Point (x, y);
 
@@ -129,6 +130,8 @@ namespace Pinta.Tools
 			var invalidate_rect = Gdk.Rectangle.Zero;
 			var brush_width = BrushWidth;
 
+			Surface = surf;
+
 			using (Drawable = new Context (surf)) {
 				Drawable.AppendPath (doc.SelectionPath);
 				Drawable.FillRule = FillRule.EvenOdd;
@@ -140,16 +143,17 @@ namespace Pinta.Tools
 				Drawable.LineCap = BrushWidth == 1 ? LineCap.Butt : LineCap.Round;
 				Drawable.Color = StrokeColor;
 
-				Drawable.Translate (brush_width / 2.0, brush_width / 2.0);
-
 				active_brush.Tool = this;
 				invalidate_rect = active_brush.DoMouseMove (x, y, LastPoint.X, LastPoint.Y);
 				active_brush.Tool = null;
 			}
 
+			Surface = null;
 			Drawable = null;
 
-			if (invalidate_rect.IsEmpty) {
+			// If we draw partially offscreen to the left or top, Cairo
+			// gives us a bogus dirty rectangle, so redraw everything
+			if (invalidate_rect.IsEmpty || invalidate_rect.Top < 0 || invalidate_rect.Left < 0) {
 				doc.Workspace.Invalidate ();
 			} else {
 				doc.Workspace.Invalidate (invalidate_rect);
