@@ -32,7 +32,7 @@ using Mono.Unix;
 
 namespace Pinta.Tools
 {
-	//[System.ComponentModel.Composition.Export (typeof (BaseTool))]
+	//[System.ComponentModel.Composition (typeof (BaseTool))]
 	public class PencilTool : BaseTool
 	{		
 		private Point last_point = point_empty;
@@ -126,8 +126,10 @@ namespace Pinta.Tools
 				
 					g.Antialias = Antialias.None;
 				
-					g.MoveTo (last_point.X, last_point.Y);
-					g.LineTo (x, y);
+					// Adding 0.5 forces cairo into the correct square:
+					// See https://bugs.launchpad.net/bugs/672232
+					g.MoveTo (last_point.X + 0.5, last_point.Y + 0.5);
+					g.LineTo (x + 0.5, y + 0.5);
 
 					g.Color = tool_color;
 					g.LineWidth = 1;
