@@ -33,6 +33,8 @@ namespace Pinta.Tools
 {
 	public abstract class SelectTool : ShapeTool
 	{
+		private PointD reset_origin;
+
 		protected SelectionHistoryItem hist;
 		public override Gdk.Key ShortcutKey { get { return Gdk.Key.S; } }
 		protected override bool ShowAntialiasingButton { get { return false; } }
@@ -51,7 +53,14 @@ namespace Pinta.Tools
 			if (is_drawing)
 				return;
 		
-			shape_origin = point;
+			reset_origin = args.Event.GetPoint ();
+
+			Document doc = PintaCore.Workspace.ActiveDocument; 
+			
+			double x = Utility.Clamp (point.X, 0, doc.ImageSize.Width - 1);
+			double y = Utility.Clamp (point.Y, 0, doc.ImageSize.Height - 1);
+
+			shape_origin = new PointD (x, y);
 			is_drawing = true;
 			
 			hist = new SelectionHistoryItem (Icon, Name);
@@ -62,11 +71,11 @@ namespace Pinta.Tools
 		{
 			double x = point.X;
 			double y = point.Y;
-
+			
 			// If the user didn't move the mouse, they want to deselect
-			int tolerance = 2;
+			int tolerance = 0;
 
-			if (Math.Abs (shape_origin.X - x) <= tolerance && Math.Abs (shape_origin.Y - y) <= tolerance) {
+			if (Math.Abs (reset_origin.X - args.Event.X) <= tolerance && Math.Abs (reset_origin.Y - args.Event.Y) <= tolerance) {
 				PintaCore.Actions.Edit.Deselect.Activate ();
 				hist.Dispose ();
 				hist = null;
