@@ -17,7 +17,7 @@ using Pinta.Core;
 
 namespace Pinta.Tools
 {
-	//[System.ComponentModel.Composition.Export (typeof (BaseTool))]
+	//[System.ComponentModel.Composition (typeof (BaseTool))]
 	public class TextTool : BaseTool
 	{
 		// Variables for dragging
@@ -29,6 +29,7 @@ namespace Pinta.Tools
 		private Point clickPoint;
 		private bool is_editing;
 		private Rectangle old_bounds = Rectangle.Zero;
+		private Rectangle old_cursor_bounds = Rectangle.Zero;
 
 		private TextEngine engine;
 
@@ -51,7 +52,7 @@ namespace Pinta.Tools
 
 		#region ToolBar
 		private ToolBarLabel font_label;
-		private ToolBarComboBox font_combo;
+		private ToolBarFontComboBox font_combo;
 		private ToolBarComboBox size_combo;
 		private ToolBarToggleButton bold_btn;
 		private ToolBarToggleButton italic_btn;
@@ -60,15 +61,13 @@ namespace Pinta.Tools
 		private ToolBarToggleButton center_alignment_btn;
 		private ToolBarToggleButton Right_alignment_btn;
 		private ToolBarLabel spacer_label;
-
-		protected void RenderFont (Gtk.CellLayout layout, Gtk.CellRenderer renderer, Gtk.TreeModel model, Gtk.TreeIter iter)
-		{
-			string fontName = (string)model.GetValue (iter, 0);
-			Gtk.CellRendererText cell = renderer as Gtk.CellRendererText;
-			cell.Text = fontName;
-			cell.Font = string.Format ("{0} 10", fontName);
-			cell.Family = fontName;
-		}
+		private ToolBarLabel fill_label;
+		private ToolBarDropDownButton fill_button;
+		private SeparatorToolItem fill_sep;
+		private ToolBarComboBox outline_width;
+		private ToolBarLabel outline_width_label;
+		private ToolBarButton outline_width_minus;
+		private ToolBarButton outline_width_plus;
 
 		protected override void OnBuildToolBar (Gtk.Toolbar tb)
 		{
@@ -86,9 +85,8 @@ namespace Pinta.Tools
 				// Default to Arial or first in list
 				int index = Math.Max (fonts.IndexOf ("Arial"), 0);
 
-				font_combo = new ToolBarComboBox (150, index, false, fonts.ToArray ());
+				font_combo = new ToolBarFontComboBox (150, index, fonts.ToArray ());
 				font_combo.ComboBox.Changed += HandleFontChanged;
-				font_combo.ComboBox.SetCellDataFunc (font_combo.CellRendererText, new CellLayoutDataFunc (RenderFont));
 			}
 
 			tb.AppendItem (font_combo);
@@ -155,6 +153,57 @@ namespace Pinta.Tools
 			
 			tb.AppendItem (Right_alignment_btn);
 
+			if (fill_sep == null)
+				fill_sep = new Gtk.SeparatorToolItem ();
+
+			tb.AppendItem (fill_sep);
+
+			if (fill_label == null)
+				fill_label = new ToolBarLabel (string.Format (" {0}: ", Catalog.GetString ("Text Style")));
+
+			tb.AppendItem (fill_label);
+
+			if (fill_button == null) {
+				fill_button = new ToolBarDropDownButton ();
+
+				fill_button.AddItem (Catalog.GetString ("Normal"), "ShapeTool.Fill.png", 0);
+				fill_button.AddItem (Catalog.GetString ("Normal and Outline"), "ShapeTool.OutlineFill.png", 1);
+				fill_button.AddItem (Catalog.GetString ("Outline"), "ShapeTool.Outline.png", 2);
+
+				fill_button.SelectedItemChanged += HandleBoldButtonToggled;
+			}
+
+			tb.AppendItem (fill_button);
+
+			if (outline_width_label == null)
+				outline_width_label = new ToolBarLabel (string.Format (" {0}: ", Catalog.GetString ("Outline width")));
+
+			tb.AppendItem (outline_width_label);
+
+			if (outline_width_minus == null) {
+				outline_width_minus = new ToolBarButton ("Toolbar.MinusButton.png", "", Catalog.GetString ("Decrease outline size"));
+				outline_width_minus.Clicked += MinusButtonClickedEvent;
+			}
+
+			tb.AppendItem (outline_width_minus);
+
+			if (outline_width == null) {
+				outline_width = new ToolBarComboBox (65, 1, true, "1", "2", "3", "4", "5", "6", "7", "8", "9",
+				"10", "11", "12", "13", "14", "15", "20", "25", "30", "35",
+				"40", "45", "50", "55");
+
+				(outline_width.Child as ComboBoxEntry).Changed += HandleSizeChanged;
+			}
+
+			tb.AppendItem (outline_width);
+
+			if (outline_width_plus == null) {
+				outline_width_plus = new ToolBarButton ("Toolbar.PlusButton.png", "", Catalog.GetString ("Increase outline size"));
+				outline_width_plus.Clicked += PlusButtonClickedEvent;
+			}
+
+			tb.AppendItem (outline_width_plus);
+
 			UpdateFontSizes ();
 		}
 
@@ -312,6 +361,35 @@ namespace Pinta.Tools
 			if (is_editing)
 				RedrawText (true, true);
 		}
+
+		protected virtual void MinusButtonClickedEvent (object o, EventArgs args)
+		{
+			if (OutlineWidth > 1)
+				OutlineWidth--;
+		}
+
+		protected virtual void PlusButtonClickedEvent (object o, EventArgs args)
+		{
+			OutlineWidth++;
+		}
+
+		protected int OutlineWidth {
+			get {
+				int width;
+				if (Int32.TryParse (outline_width.ComboBox.ActiveText, out width)) {
+					if (width > 0) {
+						(outline_width.ComboBox as Gtk.ComboBoxEntry).Entry.Text = width.ToString ();
+						return width;
+					}
+				}
+				(outline_width.ComboBox as Gtk.ComboBoxEntry).Entry.Text = "2";
+				return 2;
+			}
+			set { (outline_width.ComboBox as Gtk.ComboBoxEntry).Entry.Text = value.ToString (); }
+		}
+
+		protected bool StrokeText { get { return (int)fill_button.SelectedItem.Tag >= 1; } }
+		protected bool FillText { get { return (int)fill_button.SelectedItem.Tag <= 1; } }
 		#endregion
 
 		#region Activation/Deactivation
@@ -321,6 +399,7 @@ namespace Pinta.Tools
 			
 			// We may need to redraw our text when the color changes
 			PintaCore.Palette.PrimaryColorChanged += HandlePintaCorePalettePrimaryColorChanged;
+			PintaCore.Palette.SecondaryColorChanged += HandlePintaCorePalettePrimaryColorChanged;
 			
 			// We always start off not in edit mode
 			is_editing = false;
@@ -337,6 +416,7 @@ namespace Pinta.Tools
 
 			// Stop listening for color change events
 			PintaCore.Palette.PrimaryColorChanged -= HandlePintaCorePalettePrimaryColorChanged;
+			PintaCore.Palette.SecondaryColorChanged -= HandlePintaCorePalettePrimaryColorChanged;
 			
 			StopEditing ();
 		}
@@ -533,26 +613,30 @@ namespace Pinta.Tools
 			if (!is_editing)
 				return;
 
-			Document doc = PintaCore.Workspace.ActiveDocument;
+			try {
+				Document doc = PintaCore.Workspace.ActiveDocument;
 
-			doc.ToolLayer.Clear ();
-			doc.ToolLayer.Hidden = true;
+				doc.ToolLayer.Clear ();
+				doc.ToolLayer.Hidden = true;
 
-			if (engine.EditMode == EditingMode.Editing) {
-				SimpleHistoryItem hist = new SimpleHistoryItem (Icon, Name);
-				hist.TakeSnapshotOfLayer (doc.CurrentLayerIndex);
+				if (engine.EditMode == EditingMode.Editing) {
+					SimpleHistoryItem hist = new SimpleHistoryItem (Icon, Name);
+					hist.TakeSnapshotOfLayer (doc.CurrentLayerIndex);
 
-				// Redraw the text without the cursor,
-				// and on to the real layer
-				RedrawText (false, false);
+					// Redraw the text without the cursor,
+					// and on to the real layer
+					RedrawText (false, false);
 
-				doc.History.PushNewItem (hist);
+					doc.History.PushNewItem (hist);
+				}
+
+				engine.Clear ();
+				doc.Workspace.Invalidate (old_bounds);
+				old_bounds = Rectangle.Zero;
+				is_editing = false;
+			} catch (Exception) {
+				// Just ignore the error
 			}
-
-			engine.Clear ();
-			doc.Workspace.Invalidate (old_bounds);
-			old_bounds = Rectangle.Zero;
-			is_editing = false;
 		}
 		#endregion
 
@@ -560,7 +644,8 @@ namespace Pinta.Tools
 		private void RedrawText (bool showCursor, bool useToolLayer)
 		{
 			Cairo.ImageSurface surf;
-			
+			var invalidate_cursor = old_cursor_bounds;
+
 			if (!useToolLayer)
 				surf = PintaCore.Workspace.ActiveDocument.CurrentLayer.Surface;
 			else {
@@ -579,22 +664,41 @@ namespace Pinta.Tools
 				g.Color = PintaCore.Palette.PrimaryColor;
 
 				// Draw the text
-				Pango.CairoHelper.ShowLayout (g, engine.Layout);
+				if (FillText)
+					Pango.CairoHelper.ShowLayout (g, engine.Layout);
+
+				if (FillText && StrokeText) {
+					g.Color = PintaCore.Palette.SecondaryColor;
+					g.LineWidth = OutlineWidth;
+
+					Pango.CairoHelper.LayoutPath (g, engine.Layout);
+					g.Stroke ();
+				} else if (StrokeText) {
+					g.Color = PintaCore.Palette.PrimaryColor;
+					g.LineWidth = OutlineWidth;
+
+					Pango.CairoHelper.LayoutPath (g, engine.Layout);
+					g.Stroke ();
+				}
 
 				if (showCursor) {
 					var loc = engine.GetCursorLocation ();
 
 					g.Antialias = Cairo.Antialias.None;
 					g.DrawLine (new Cairo.PointD (loc.X, loc.Y), new Cairo.PointD (loc.X, loc.Y + loc.Height), new Cairo.Color (0, 0, 0, 1), 1);
+					
+					loc.Inflate (2, 10);
+					old_cursor_bounds = loc;
 				}
 
 				g.Restore ();
 			}
 
 			Rectangle r = engine.GetLayoutBounds ();
-			r.Inflate (10, 10);
+			r.Inflate (10 + OutlineWidth, 10 + OutlineWidth);
 
 			PintaCore.Workspace.Invalidate (old_bounds);
+			PintaCore.Workspace.Invalidate (invalidate_cursor);
 			PintaCore.Workspace.Invalidate (r);
 
 			old_bounds = r;
